@@ -1,17 +1,24 @@
-#' Tools for joining lists of networks, graphs, and matrices
+#' Joining lists of networks, graphs, and matrices
 #' 
 #' @description
 #'   These functions offer tools for joining lists of manynet-consistent objects
-#'   (matrices, igraph, tidygraph, or network objects).
-#'   Joining expects a list of objects and returns a single network object.
+#'   (matrices, igraph, tidygraph, or network objects) into a single object.
+#'   
+#'   - `from_subgraphs()` modifies a list of subgraphs into a single tidygraph.
+#'   - `from_egos()` modifies a list of ego networks into a whole tidygraph
+#'   - `from_waves()` modifies a list of network waves into a longitudinal tidygraph.
+#'   - `from_slices()` modifies a list of time slices of a network into 
+#'   a dynamic tidygraph.
+#'   - `from_ties()` modifies a list of different ties into a multiplex tidygraph
 #' @name from
-#' @family manipulations
-#' @inheritParams reformat
+#' @family modifications
+#' @param netlist A list of network, igraph, tidygraph, matrix, or edgelist objects.
+#' @param netnames A character vector of names for the different network objects,
+#'   if not already named within the list.
 #' @return A tidygraph object combining the list of network data.
 NULL
 
-#' @describeIn from Returns a single network object
-#'  from a list of subgraphs.
+#' @rdname from
 #' @importFrom igraph graph_from_data_frame as_data_frame set_vertex_attr
 #' @examples
 #' ison_adolescents %>%
@@ -19,11 +26,11 @@ NULL
 #'   to_subgraphs(attribute = "unicorn") %>%
 #'   from_subgraphs()
 #' @export
-from_subgraphs <- function(.data) {
-  if (!is.list(.data[1])) {
+from_subgraphs <- function(netlist) {
+  if (!is.list(netlist[1])) {
     stop("Please declare a list of subgraphs. ")
   }
-  ann <- lapply(.data, as_igraph)
+  ann <- lapply(netlist, as_igraph)
   out <- ann[[1]]
   for (i in seq_along(ann)[-1]) {
     out <- join_nodes(out, ann[[i]])
@@ -36,8 +43,7 @@ from_subgraphs <- function(.data) {
   as_tidygraph(out)
 }
 
-#' @describeIn from Returns a single network object
-#'  from a list of egos.
+#' @rdname from
 #' @importFrom igraph graph_from_data_frame as_data_frame
 #' @importFrom dplyr distinct
 #' @examples
@@ -45,11 +51,11 @@ from_subgraphs <- function(.data) {
 #'   to_egos() %>%
 #'   from_egos()
 #' @export
-from_egos <- function(.data) {
-  if (!is.list(.data[1])) {
+from_egos <- function(netlist) {
+  if (!is.list(netlist[1])) {
     stop("Please declare a list of egos.")
   }
-  ann <- lapply(.data, as_igraph)
+  ann <- lapply(netlist, as_igraph)
   out <- igraph::as_data_frame(ann[[1]])
   for (i in seq_along(ann)[-1]){
     out <- rbind(out, igraph::as_data_frame(ann[[i]]))
@@ -57,8 +63,7 @@ from_egos <- function(.data) {
   as_tidygraph(igraph::graph_from_data_frame(dplyr::distinct(out)))
 }
 
-#' @describeIn from Returns a single network object
-#'  from a list of waves.
+#' @rdname from 
 #' @importFrom igraph graph_from_data_frame as_data_frame
 #' @examples
 #' ison_adolescents %>%
@@ -66,11 +71,11 @@ from_egos <- function(.data) {
 #'   to_waves(attribute = "wave") %>%
 #'   from_waves()
 #' @export
-from_waves <- function(.data) {
-  if (!is.list(.data[1])) {
+from_waves <- function(netlist) {
+  if (!is.list(netlist[1])) {
     stop("Please declare a list of waves.")
   }
-  ann <- lapply(.data, as_igraph)
+  ann <- lapply(netlist, as_igraph)
   out <- igraph::as_data_frame(ann[[1]])
   for (i in seq_along(ann)[-1]){
     out <- rbind(out, igraph::as_data_frame(ann[[i]]))
@@ -78,8 +83,7 @@ from_waves <- function(.data) {
   as_tidygraph(igraph::graph_from_data_frame(out))
 }
 
-#' @describeIn from Returns a single network object
-#'  from a list of slices.
+#' @rdname from 
 #' @param remove.duplicates Should duplicates be removed?
 #' By default FALSE.
 #' If TRUE, duplicated edges are removed.
@@ -92,9 +96,9 @@ from_waves <- function(.data) {
 #'   to_slices(slice = c(5,7)) %>%
 #'   from_slices()
 #' @export
-from_slices <- function(.data, remove.duplicates = FALSE) {
-  if (is.list(.data[1])) {
-    ann <- lapply(.data, as_igraph)
+from_slices <- function(netlist, remove.duplicates = FALSE) {
+  if (is.list(netlist[1])) {
+    ann <- lapply(netlist, as_igraph)
     out <- igraph::as_data_frame(ann[[1]])
     for (i in seq_along(ann)[-1]){
       out <- rbind(out, igraph::as_data_frame(ann[[i]]))
@@ -107,3 +111,21 @@ from_slices <- function(.data, remove.duplicates = FALSE) {
     message("Only one slice is available, cannot be joined.")
   }
 }
+
+#' @rdname from
+#' @export
+from_ties <- function(netlist, netnames){
+  stopifnot(is_list(netlist))
+  if(is.null(names(netlist))){
+    if(!missing(netnames)){
+      names(netlist) <- netnames
+    } else stop(paste("Please name the elements of the list of networks",
+                      "or provide a vector of names for them."))
+  }
+  netlist <- lapply(seq_along(netlist), 
+                    function(x) if(is_multiplex(netlist[[x]])){
+                      netlist[[x]] } else { 
+                        mutate_ties(netlist[[x]], type = names(netlist)[x])
+                        })
+  Reduce(tidygraph::graph_join, netlist)
+}
