@@ -37,8 +37,7 @@ test_that("star creation works", {
 test_that("tree creation works", {
   expect_true(!is_twomode(create_tree(5)))
   expect_true(is_twomode(create_tree(c(5,6))))
-  expect_equal(unname(as_matrix(create_tree(c(2,2)))),
-               matrix(c(1,1,1,0),2,2))
+  expect_equal(unname(as_matrix(create_tree(c(2,2)))), matrix(c(1,1,1,0),2,2))
   expect_error(create_tree(c(5,5,5)), "single integer")
 })
 
@@ -70,7 +69,7 @@ test_that("core-periphery creation works", {
 #   expect_s3_class(create_nest(2,4, as = "tidygraph"), "tbl_graph")
 # })
 
-test_that("nest creation works", {
+test_that("explicit creation works", {
   expect_true(is_directed(create_explicit(A -+ B, B -+ C, A +-+ C, D)))
   expect_false(manynet::is_weighted(create_explicit(A -+ B, B -+ C, A +-+ C, D)))
   expect_length(create_explicit(A -+ B, B -+ C, A +-+ C, D), 4)
